summaryrefslogtreecommitdiffstats
path: root/plugins/audio/audio-api.h
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/audio/audio-api.h')
-rw-r--r--plugins/audio/audio-api.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/plugins/audio/audio-api.h b/plugins/audio/audio-api.h
index 1cf54fc0..12f70a8e 100644
--- a/plugins/audio/audio-api.h
+++ b/plugins/audio/audio-api.h
@@ -22,9 +22,9 @@
#include "audio-alsa.h"
/* global plugin handle, should store everything we may need */
-/*typedef struct {
+typedef struct {
int devCount;
-} pluginHandleT;*/
+} pluginHandleT;
/* structure holding one audio card with current usage status */
typedef struct {
@@ -34,11 +34,12 @@ typedef struct {
/* private client context [will be destroyed when client leaves] */
typedef struct {
- audioDevT *radio; /* pointer to client audio card */
- int idx; /* audio card index within global array */
- unsigned int volume; /* audio volume : 0-100 */
- unsigned int channels; /* audio channels : 1(mono)/2(stereo)... */
- unsigned char mute; /* audio muted : 0(false)/1(true) */
+ audioDevT *radio; /* pointer to client audio card */
+ int idx; /* audio card index within global array */
+ unsigned int volume; /* audio volume : 0-100 */
+ unsigned int channels; /* audio channels : 1(mono)/2(stereo)... */
+ unsigned char mute; /* audio muted : 0(false)/1(true) */
+ unsigned char is_playing; /* audio is playing: 0(false)/1(true) */
} audioCtxHandleT;